Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(327)

Unified Diff: net/http/http_network_session.h

Issue 1572753003: QUIC - Allow cronet apps to specify how many server configs are to be (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix comments in Patch set 4 Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/cronet/url_request_context_config_unittest.cc ('k') | net/http/http_network_session.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/http/http_network_session.h
diff --git a/net/http/http_network_session.h b/net/http/http_network_session.h
index 09b4d7e7a8d25bd7495b2fabb653d2e0399f3e99..9f9848963824798cbb3b02047e4f7f350dbd0592 100644
--- a/net/http/http_network_session.h
+++ b/net/http/http_network_session.h
@@ -154,8 +154,9 @@ class NET_EXPORT HttpNetworkSession
// Delay starting a TCP connection when QUIC believes it can speak
// 0-RTT to a server.
bool quic_delay_tcp_race;
- // Store server configs in HttpServerProperties, instead of the disk cache.
- bool quic_store_server_configs_in_properties;
+ // Maximum number of server configs that are to be stored in
+ // HttpServerProperties, instead of the disk cache.
+ size_t quic_max_server_configs_stored_in_properties;
// If not empty, QUIC will be used for all connections to this origin.
HostPortPair origin_to_force_quic_on;
// Source of time for QUIC connections. Will be owned by QuicStreamFactory.
« no previous file with comments | « components/cronet/url_request_context_config_unittest.cc ('k') | net/http/http_network_session.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698